==> mule-module-spring-config-4.6.22-20250808.180005-19-test-sources.jar: org/mule/runtime/config/internal/dsl/spring/BeanDefinitionFactoryRepresentationTestCase.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.config.internal.dsl.spring;

import static org.mule.runtime.api.component.Component.Annotations.NAME_ANNOTATION_KEY;
import static org.mule.runtime.config.internal.dsl.spring.BeanDefinitionFactory.resolveProcessorRepresentation;
import static org.mule.runtime.dsl.api.component.config.DefaultComponentLocation.from;
import static org.mule.test.allure.AllureConstants.Logging.LOGGING;
import static org.mule.test.allure.AllureConstants.Logging.LoggingStory.FLOW_STACK;

import static org.hamcrest.CoreMatchers.is;
import static org.junit.Assert.assertThat;

import org.mule.runtime.ast.internal.DefaultComponentMetadataAst;
import org.mule.tck.junit4.AbstractMuleTestCase;

import org.junit.Test;

import io.qameta.allure.Feature;
import io.qameta.allure.Story;

@Feature(LOGGING)
@Story(FLOW_STACK)
public class BeanDefinitionFactoryRepresentationTestCase extends AbstractMuleTestCase {

  @Test
  public void withFailingProcessorNoPathResolver() {
    assertThat(resolveProcessorRepresentation("BeanDefinitionFactoryRepresentationTestCase", from("Mock@1"),
                                              DefaultComponentMetadataAst.builder()
                                                  .setFileName("unknown")
                                                  .build()),
               is("Mock@1 @ BeanDefinitionFactoryRepresentationTestCase:unknown:-1"));
  }

  @Test
  public void withFailingProcessorPathResolver() {
    assertThat(resolveProcessorRepresentation("BeanDefinitionFactoryRepresentationTestCase",
                                              from("flow/processor"),
                                              DefaultComponentMetadataAst.builder()
                                                  .setFileName("muleApp.xml")
                                                  .setStartLine(10)
                                                  .build()),
               is("flow/processor @ BeanDefinitionFactoryRepresentationTestCase:muleApp.xml:10"));
  }

  @Test
  public void withFailingProcessorNotPathResolver() {
    assertThat(resolveProcessorRepresentation("BeanDefinitionFactoryRepresentationTestCase", from("Mock@1"),
                                              DefaultComponentMetadataAst.builder()
                                                  .setFileName("unknown")
                                                  .build()),
               is("Mock@1 @ BeanDefinitionFactoryRepresentationTestCase:unknown:-1"));
  }

  @Test
  public void withAnnotatedFailingProcessorNoPathResolver() {
    assertThat(resolveProcessorRepresentation("BeanDefinitionFactoryRepresentationTestCase", from("Mock@1"),
                                              DefaultComponentMetadataAst.builder()
                                                  .setFileName("muleApp.xml")
                                                  .setStartLine(10)
                                                  .putDocAttribute(NAME_ANNOTATION_KEY.getLocalPart(), "Mock Component")
                                                  .build()),
               is("Mock@1 @ BeanDefinitionFactoryRepresentationTestCase:muleApp.xml:10 (Mock Component)"));
  }

  @Test
  public void withAnnotatedFailingProcessorPathResolver() {
    assertThat(resolveProcessorRepresentation("BeanDefinitionFactoryRepresentationTestCase",
                                              from("flow/processor"),
                                              DefaultComponentMetadataAst.builder()
                                                  .setFileName("muleApp.xml")
                                                  .setStartLine(10)
                                                  .putDocAttribute(NAME_ANNOTATION_KEY.getLocalPart(), "Mock Component")
                                                  .build()),
               is("flow/processor @ BeanDefinitionFactoryRepresentationTestCase:muleApp.xml:10 (Mock Component)"));
  }

  @Test
  public void withAnnotatedFailingProcessorNotPathResolver() {
    assertThat(resolveProcessorRepresentation("BeanDefinitionFactoryRepresentationTestCase", from("Mock@1"),
                                              DefaultComponentMetadataAst.builder()
                                                  .setFileName("muleApp.xml")
                                                  .setStartLine(10)
                                                  .putDocAttribute(NAME_ANNOTATION_KEY.getLocalPart(), "Mock Component")
                                                  .build()),
               is("Mock@1 @ BeanDefinitionFactoryRepresentationTestCase:muleApp.xml:10 (Mock Component)"));
  }

}

==> mule-module-spring-config-4.8.4-20250120.191458-1-test-sources.jar: org/mule/runtime/config/internal/dsl/spring/BeanDefinitionFactoryRepresentationTestCase.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.config.internal.dsl.spring;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.mule.runtime.api.component.Component.Annotations.NAME_ANNOTATION_KEY;
import static org.mule.runtime.config.internal.dsl.spring.BeanDefinitionFactory.resolveProcessorRepresentation;
import static org.mule.runtime.dsl.api.component.config.DefaultComponentLocation.from;

import org.mule.runtime.ast.internal.DefaultComponentMetadataAst;
import org.mule.tck.junit4.AbstractMuleTestCase;

import org.junit.Test;

public class BeanDefinitionFactoryRepresentationTestCase extends AbstractMuleTestCase {

  @Test
  public void withFailingProcessorNoPathResolver() {
    assertThat(resolveProcessorRepresentation("BeanDefinitionFactoryRepresentationTestCase", from("Mock@1"),
                                              DefaultComponentMetadataAst.builder()
                                                  .setFileName("unknown")
                                                  .build()),
               is("Mock@1 @ BeanDefinitionFactoryRepresentationTestCase:unknown:-1"));
  }

  @Test
  public void withFailingProcessorPathResolver() {
    assertThat(resolveProcessorRepresentation("BeanDefinitionFactoryRepresentationTestCase",
                                              from("flow/processor"),
                                              DefaultComponentMetadataAst.builder()
                                                  .setFileName("muleApp.xml")
                                                  .setStartLine(10)
                                                  .build()),
               is("flow/processor @ BeanDefinitionFactoryRepresentationTestCase:muleApp.xml:10"));
  }

  @Test
  public void withFailingProcessorNotPathResolver() {
    assertThat(resolveProcessorRepresentation("BeanDefinitionFactoryRepresentationTestCase", from("Mock@1"),
                                              DefaultComponentMetadataAst.builder()
                                                  .setFileName("unknown")
                                                  .build()),
               is("Mock@1 @ BeanDefinitionFactoryRepresentationTestCase:unknown:-1"));
  }

  @Test
  public void withAnnotatedFailingProcessorNoPathResolver() {
    assertThat(resolveProcessorRepresentation("BeanDefinitionFactoryRepresentationTestCase", from("Mock@1"),
                                              DefaultComponentMetadataAst.builder()
                                                  .setFileName("muleApp.xml")
                                                  .setStartLine(10)
                                                  .putDocAttribute(NAME_ANNOTATION_KEY.getLocalPart(), "Mock Component")
                                                  .build()),
               is("Mock@1 @ BeanDefinitionFactoryRepresentationTestCase:muleApp.xml:10 (Mock Component)"));
  }

  @Test
  public void withAnnotatedFailingProcessorPathResolver() {
    assertThat(resolveProcessorRepresentation("BeanDefinitionFactoryRepresentationTestCase",
                                              from("flow/processor"),
                                              DefaultComponentMetadataAst.builder()
                                                  .setFileName("muleApp.xml")
                                                  .setStartLine(10)
                                                  .putDocAttribute(NAME_ANNOTATION_KEY.getLocalPart(), "Mock Component")
                                                  .build()),
               is("flow/processor @ BeanDefinitionFactoryRepresentationTestCase:muleApp.xml:10 (Mock Component)"));
  }

  @Test
  public void withAnnotatedFailingProcessorNotPathResolver() {
    assertThat(resolveProcessorRepresentation("BeanDefinitionFactoryRepresentationTestCase", from("Mock@1"),
                                              DefaultComponentMetadataAst.builder()
                                                  .setFileName("muleApp.xml")
                                                  .setStartLine(10)
                                                  .putDocAttribute(NAME_ANNOTATION_KEY.getLocalPart(), "Mock Component")
                                                  .build()),
               is("Mock@1 @ BeanDefinitionFactoryRepresentationTestCase:muleApp.xml:10 (Mock Component)"));
  }

}
